# Rundeck
A role for deploying Rundeck. All data from Rundeck are stored in
`"/var/lib/rundeck"` and `"/var/log/rundeck"` directories.

## Versions
* *docker/rundeck* 3.3.7
* *python2/ansible* 2.9.15

## Roles
* [docker](https://projects.task.gda.pl/ansible-roles/docker)
* [service](https://projects.task.gda.pl/ansible-roles/service)

## Managed hosts:
* `docker` installed on each host

## Role Actions
* [`deploy`](#deploy-action)
* [`users`](#users-action)
* [`projects`](#projects-action)

## Role API
### General Variables
* `rundeck_root_url` - url of Rundeck application, should contain
    protocol and port (e.g. `https://rundeck.domain.com:8443`)
* `rundeck_admin_password` - password for the `admin` user in Rundeck.
* *(optional)* `rundeck_bind_ip` - the IP address of the host machine,
    to which the Rundeck container will bind (default: `"0.0.0.0"`, bind to
    all interfaces)
* *(optional)* `rundeck_bind_port` - the port of the host machine,
    to which the Rundeck container will bind (default: `4440`)

### `deploy` action
Deploys Rundeck on a host.

#### Variables
* `rundeck_user_id` - id of rundeck user in container. This user will be
    owner of all files stored in `"/var/lib/rundeck"` directory.
* `rundeck_user_group_id` - group id of rundeck user in container
* `rundeck_database_password` - password for the database user; the
    database user's name is set to `rundeck` and cannot be changed
* *(optional)* `rundeck_service_name` - name of the *systemd* service
    with Rundeck and its dependencies (default: `"rundeck"`)
* *(optional)* `rundeck_plugins` - a list of extra plugins for Rundeck
    (default: `[]`), in the following format:
    * `name` - name of rundeck plugin
    * `url` - url to plugin jar file
    * *(optional)* `headers` - dictionary with request headers, can be used
        if e.g. authorization is required
* *(optional)* `rundeck_behind_reverse_proxy` - is Rundeck behind HTTPS proxy (default: `yes`)
* *(optional)* `rundeck_enable_ldap_authentication` - should Rundeck authenticate
    users with LDAP (default: `no`)

##### Variables when enable LDAP authentication
* `rundeck_ldap_url` - URL of external LDAP server
* `rundeck_ldap_base_distinguished_name` - user distinguished name in LDAP
* `rundeck_ldap_password` - password for LDAP user
* `rundeck_ldap_users_base_distinguished_name` - base distinguished name to search for users
* *(optional)* `rundeck_ldap_user_roles_attribute` - attribute name for username, used
    when searching for user role membership by distinguished name (default: `"uid"`)
* *(optional)* `rundeck_ldap_user_id_attribute` - attribute name to identify user by username
    (default: `"cn"`)
* *(optional)* `rundeck_ldap_user_password_attribute` - attribute name for user password
    (default: `"userPassword"`)
* *(optional)* `rundeck_ldap_user_object_class_attribute` - attribute name for user object
    class (default: `"inetOrgPerson"`)
* *(optional)* `rundeck_ldap_user_first_name_attribute` - attribute name for user's first
    name (default: `"givenName"`)
* *(optional)* `rundeck_ldap_user_last_name_attribute` - attribute name for user's last
    name (default: `"sn"`)
* *(optional)* `rundeck_ldap_user_email_attribute` - attribute name for user's email address
    (default: `"mail"`)
* `rundeck_ldap_role_base_distinguished_name` - base distinguished name for role membership search
* *(optional)* `rundeck_ldap_role_name_attribute` - attribute name for role name (default:
    `"roleName"`)
* *(optional)* `rundeck_ldap_role_member_attribute` - attribute name for a role that would
    contain a user's distinguished name (default: `"uniqueMember"`)
* *(optional)* `rundeck_ldap_role_username_member_attribute` - attribute name for a role
    that would contain a user's username. If set, this overrides the `rundeck_ldap_role_member_attribute`
    behavior (by default not defined).
* *(optional)* `rundeck_ldap_role_object_class` - object class for role (default: `"groupOfUniqueNames"`)

### `users` action
Creates users in Rundeck.

#### Variables
* `rundeck_users` - list of users to add in Rundeck, all users existing
    in Rundeck but not defined on this list will be removed.
    * `name` - user name (for logging in to Rundeck)
    * `password` - user password hashed using MD5, user can generate hash
        using following command: `echo -n ONES_PASSWORD | md5sum`
    * `roles` - a list of user roles. Role support only default roles
        defined in rundeck: `admin`, `user`, `architect`,
        `deploy`, `build`

#### Additional Comments
**WARNING**
* All users have access to all projects at this moment, only roles could
    be defined (per whole system). More about configuring access policies:

    * [authenticating users](http://rundeck.org/docs/administration/authenticating-users.html)
    * [access control policy](http://rundeck.org/docs/administration/access-control-policy.html)
* User `admin` should not be listed on `rundeck_users` list.

### `projects` action
Configures projects and jobs in Rundeck.

#### Variables
* `rundeck_projects` - a list of projects definitions
    * `name` - the name of the project
    * *(optional)* `credentials` - list of credentials to use in jobs
        * `name` - the name to store in the key storage
        * `content` - the raw content of the key or a plain password
        * `type` - the type of the key (default: `"password"`); the
            possible values are:
            * `private` (when the content is a private key)
            * `public` (when the content is a public key)
            * `password`
    * *(optional)* `default_key` - the name of one of the keys specified in the
        `credentials` field; this key will be used by default for all
        jobs in the project
    * *(optional)* `configuration` - dictionary with options which will
        be set for project. Configuration options are not desribed precisely
        in official [documentation](https://docs.rundeck.com/docs/administration/configuration/index.html).

        Best way to configure project is GUI configuration. Click on
        `"Edit configuration File"` after finish configuration and copy
        configuration options to project definition.

        By default projects is configured to have only one host inventory
        (Rundeck host).
    * *(optional)* `jobs` - list of jobs defined for this project, all
        jobs exisiting in Rundeck but not defined in this list will be
        removed.
        * `name` - name of a job
        * `description` - description of a job
        * `options` - additional options (variables) which will be passed
            to job ([defining options](https://docs.rundeck.com/docs/manual/job-options.html))
        * `script` - dictionary describing job script to execute with following keys:
            * *(optional)* `workspace` - enable creating workspace for job execution.
                Workspace directory will be created before execution of defined job
                script. If set to `yes` two environment variables will be made available:
                  * `RUNDECK_JOB_WORKSPACE` - path to workspace directory in Rundeck docker
                      container
                  * `RUNDECK_HOST_JOB_WORKSPACE` - path to workspace directory on machine
                      where Rundeck container is deployed
                (default: `yes`).
            * `content` - content of job script definition

            :warning:**BE CAUTIOUS:**:warning: If in the defined script it is necessary to use any password or other sensitive
            data do not write it plaintext. Use for this purpose `options`, then inside script every option can be access by
            `@option.{{ option_name }}@` entry.
        * *(optional)* `notification` - defines a notification for the job
            [see docs](https://docs.rundeck.com/docs/manual/creating-jobs.html#job-notifications)
        * *(optional)* `schedule` - job schedule in crontab format [see docs](https://docs.rundeck.com/docs/manual/creating-jobs.html#creating-a-job).
            When option is not defined job will not be scheduled.
        * *(optional)* `timezone` - a valid time zone, either an abbreviation
            such as "UTC", a full name such as "Europe/Warsaw", or a custom
            ID such as "GMT+1:00" (by default not defined)

## Update
Update may require some additional steps, please refer to [UPDATE.md](UPDATE.md) for more details.

## Additional Resources
* [Rundeck official page](http://rundeck.org/)
* [Rundeck container](https://projects.task.gda.pl/containers/rundeck)

## License
[MIT](LICENSE.md)

## Author Information
[Centre of Informatics - Tricity Academic Supercomputer & networK (CI TASK)](https://task.gda.pl/home-en)
